==> openshift-model-5.10.1-sources.jar: io/fabric8/openshift/api/model/GroupListBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class GroupListBuilder extends io.fabric8.openshift.api.model.GroupListFluentImpl<io.fabric8.openshift.api.model.GroupListBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.GroupList,io.fabric8.openshift.api.model.GroupListBuilder>{
  public GroupListBuilder() {
    this(false);
  }
  public GroupListBuilder(java.lang.Boolean validationEnabled) {
    this(new GroupList(), validationEnabled);
  }
  public GroupListBuilder(io.fabric8.openshift.api.model.GroupListFluent<?> fluent) {
    this(fluent, false);
  }
  public GroupListBuilder(io.fabric8.openshift.api.model.GroupListFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new GroupList(), validationEnabled);
  }
  public GroupListBuilder(io.fabric8.openshift.api.model.GroupListFluent<?> fluent,io.fabric8.openshift.api.model.GroupList instance) {
    this(fluent, instance, false);
  }
  public GroupListBuilder(io.fabric8.openshift.api.model.GroupListFluent<?> fluent,io.fabric8.openshift.api.model.GroupList instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withItems(instance.getItems()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public GroupListBuilder(io.fabric8.openshift.api.model.GroupList instance) {
    this(instance,false);
  }
  public GroupListBuilder(io.fabric8.openshift.api.model.GroupList instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.GroupListFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.GroupList build() {
    GroupList buildable = new GroupList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    GroupListBuilder that = (GroupListBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-6.3.1-sources.jar: io/fabric8/openshift/api/model/GroupListBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class GroupListBuilder extends GroupListFluentImpl<GroupListBuilder> implements VisitableBuilder<GroupList,GroupListBuilder>{
  public GroupListBuilder() {
    this(false);
  }
  public GroupListBuilder(Boolean validationEnabled) {
    this(new GroupList(), validationEnabled);
  }
  public GroupListBuilder(GroupListFluent<?> fluent) {
    this(fluent, false);
  }
  public GroupListBuilder(GroupListFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new GroupList(), validationEnabled);
  }
  public GroupListBuilder(GroupListFluent<?> fluent,GroupList instance) {
    this(fluent, instance, false);
  }
  public GroupListBuilder(GroupListFluent<?> fluent,GroupList instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withItems(instance.getItems()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public GroupListBuilder(GroupList instance) {
    this(instance,false);
  }
  public GroupListBuilder(GroupList instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  GroupListFluent<?> fluent;
  Boolean validationEnabled;
  public GroupList build() {
    GroupList buildable = new GroupList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
